==> lnl-2.1.20.tar.gz: lnl-2.1.20/src/fight.h <==
/*****************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   e-mail: bowkenken@users.sourceforge.jp
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: fight.h,v 1.16 2003/11/19 13:19:13 bowkenken Exp $
*****************************************************************/

#ifndef	FIGHT_H
#define	FIGHT_H

#include	"spell_kind.h"
#include	"fx.h"
#include	"resi.h"

#define	CHR_ATACK_MAX_N	(4 + 1)

typedef enum {
	ATTACK_KIND_NULL,
	ATTACK_KIND_SPELL,	/* ˡ */
	ATTACK_KIND_PUNCH,	/*  */
	ATTACK_KIND_KICK,	/*  */
	ATTACK_KIND_KNOCK,	/* á */
	ATTACK_KIND_SLASH,	/* ڤ */
	ATTACK_KIND_STING,	/* ͤ */
	ATTACK_KIND_MOW,	/* ʧ */
	ATTACK_KIND_SHOOT,	/* ͤ */
	ATTACK_KIND_THROW,	/* ꤲĤ */
	ATTACK_KIND_BITE,	/*  */
	ATTACK_KIND_CLAW,	/* ߤ */
	ATTACK_KIND_NIP,	/*  */
	ATTACK_KIND_STRANGLE,	/* Ĥ */
	ATTACK_KIND_TACKLE,	/* ֤Ĥ */
	ATTACK_KIND_TOUCH,	/*  */
	ATTACK_KIND_INDICATE,	/* ؤ */
	ATTACK_KIND_KISS,	/*  */
	ATTACK_KIND_SEDUCE,	/* ͶǤ */
	ATTACK_KIND_CARESS_BUST,	/* 򿨤 */
	ATTACK_KIND_CARESS_HIP,	/* Ǥ */
	ATTACK_KIND_CARESS_CROTCH,	/* Դ֤Ǥ */
	ATTACK_KIND_MAX_N,
} attack_kind_t;

typedef struct {
	attack_kind_t	kind;
	ratio_t	ratio;
	bool_t	flg_throw, flg_monk;
	rate_t	hit, crtcl, dam;
	resi_kind_t	resi_kind;
	fx_kind_t	fx_kind;
	long	fx_turn;
	spell_kind_t	spell;
	extent_kind_t	extent;
	n_msg_t	spell_fmt;
} attack_t;

#endif	/* FIGHT_H */

==> lnl-2.1.30.tar.gz: lnl-2.1.30/src/fight.h <==
/*****************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: fight.h,v 1.26 2004/07/26 10:02:44 bowkenken Exp $
*****************************************************************/

#ifndef	FIGHT_H
#define	FIGHT_H

/* Ʈ */

#include	"spell-kind.h"
#include	"fx.h"
#include	"resi.h"

/* ǡκ */

#define	CHR_ATACK_MAX_N	(4 + 1)

/* μ */

typedef enum {
	ATTACK_KIND_NULL,
	ATTACK_KIND_SPELL,	/* ˡ */
	ATTACK_KIND_SPELL_SELF,	/* ˡ */
	ATTACK_KIND_SPELL_FRIEND,	/* ˡ */
	ATTACK_KIND_PUNCH,	/*  */
	ATTACK_KIND_KICK,	/*  */
	ATTACK_KIND_KNOCK,	/* á */
	ATTACK_KIND_SLASH,	/* ڤ */
	ATTACK_KIND_STING,	/* ɤ */
	ATTACK_KIND_MOW,	/* ʧ */
	ATTACK_KIND_SHOOT,	/* ͤ */
	ATTACK_KIND_THROW,	/* ꤲĤ */
	ATTACK_KIND_BITE,	/*  */
	ATTACK_KIND_PECK,	/* ͤäĤ */
	ATTACK_KIND_CLAW,	/* ߤ */
	ATTACK_KIND_NIP,	/*  */
	ATTACK_KIND_STRANGLE,	/* Ĥ */
	ATTACK_KIND_TACKLE,	/* ֤Ĥ */
	ATTACK_KIND_TOUCH,	/*  */
	ATTACK_KIND_INDICATE,	/* ؤ */
	ATTACK_KIND_KISS,	/*  */
	ATTACK_KIND_SEDUCE,	/* ͶǤ */
	ATTACK_KIND_CARESS_BUST,	/* 򿨤 */
	ATTACK_KIND_CARESS_HIP,	/* Ǥ */
	ATTACK_KIND_CARESS_CROTCH,	/* Դ֤Ǥ */
	ATTACK_KIND_MAX_N,
} attack_kind_t;

/* ǡ */

typedef struct {
	/*  */
	attack_kind_t	kind;

	/* Ψ */
	ratio_t	ratio;

	/* ꤲե饰Ʈե饰 */
	bool_t	flg_throw, flg_monk;

	/*  */
	rate_t	hit, crtcl, dam;

	/* 񹳤μ */
	resi_kind_t	resi_kind;

	/* Ⱦ */
	long	range_bash, range_throw;

	/* ե */
	fx_kind_t	fx_kind;
	/* եȤΥ */
	long	fx_turn;

	/* ȯưʸ */
	spell_kind_t	spell;
	/* ʸθϰ */
	extent_kind_t	extent;
	/* ʸ̾ */
	n_msg_t	spell_fmt;
} attack_t;

#endif	/* FIGHT_H */
